This is different from other classes. The metadata is read where the dimensions in pixels can be found. The image itself is not read into memory here.
Usage
# S4 method for class 'BioFormatsImage'
dim(x)Arguments
- x
A
BioFormatsImageobject.
Value
An integer vector of length 5 showing the number of rows and columns
in the full resolution image. The 5 dimensions are in the order of XYCZT:
x, y, channel, z, and time. This is not changed by transformations. Use
ext to see the extent after transformation.
See also
Other image methods:
SFE-image,
affineImg(),
cropImg(),
dim,ExtImage-method,
ext(),
imgRaster(),
imgSource(),
mirrorImg(),
rotateImg(),
scaleImg(),
translateImg(),
transposeImg()