This method exists to make the output of dim() for ExtImage
consistent with that of Image which ExtImage inherits from,
overriding the VirtualSpatialImage method.
Usage
# S4 method for class 'ExtImage'
dim(x)Arguments
- x
A
ExtImageobject.
Value
An integer vector. As in EBImage, the first element indicates
number of pixels in the x direction, or number of columns in the image, and
the second element indicates the number of pixels in the y direction. This is
unlike array indexing.
See also
Other image methods:
SFE-image,
affineImg(),
cropImg(),
dim,BioFormatsImage-method,
ext(),
imgRaster(),
imgSource(),
mirrorImg(),
rotateImg(),
scaleImg(),
translateImg(),
transposeImg()